/****************************************************************************/
/*  Test DMX512 + MOD-24LR / nrf24L01                                       */
/****************************************************************************/
/*  LEnsE / Julien VILLEMEJANE       /   Institut d'Optique Graduate School */
/****************************************************************************/
/*  Brochage                                                                */
/*      TO COMPLETE                                                         */
/****************************************************************************/
/*  Test réalisé sur Nucléo-L476RG                                          */
/****************************************************************************/


/****************************************************************************/
/*  Code last updated on March, 27th 2023 by Matheus BELISARIO DE ABREU,    */
/*  Ziyad BENKHADAJ, Alice RENAUX, Henrique SILVESTRE and Clarice VELLOSO.  */
/****************************************************************************/


#include    "mbed.h"
#include    "DMX_MIDI.h"
#include    "projecteurs.h"
#include    "controleurs.h"

Serial          debug_pc(USBTX, USBRX); //connexion au PC
InterruptIn     bp_int(USER_BUTTON);
DigitalOut      debug_out(D13);

////////////////////////////////////////////////////////////
///////////////// définition des fonctions /////////////////

void define_color();

void define_color(int R, int G, int B, char velocity_data) {

//On récupère les données de note et de vélocité que l'on traduit en un signal DMX : note = couleur et 2*vélocité = luminosité.

    //LED 1
    dmx_data[32] = 0;
    dmx_data[35] = velocity_data*2; // luminosité
    dmx_data[36] = R; // rouge
    dmx_data[37] = G; // vert
    dmx_data[38] = B; // bleu
    //LED 2
    dmx_data[40] = 0;
    dmx_data[43] = velocity_data*2; // luminosité
    dmx_data[44] = R; // rouge
    dmx_data[45] = G; // vert
    dmx_data[46] = B; // bleu
    //LED 3
    dmx_data[48] = 0;
    dmx_data[51] = velocity_data*2; // luminosité
    dmx_data[52] = R; // rouge
    dmx_data[53] = G; // vert
    dmx_data[54] = B; // bleu
    //LED 4
    dmx_data[56] = 0;
    dmx_data[59] = velocity_data*2; // luminosité
    dmx_data[60] = R; // rouge
    dmx_data[61] = G; // vert
    dmx_data[62] = B; // bleu
}

void pattern_1(){
    //lampe 1
    dmx_data[32] = 0; //canal 1 : entre 0 et 10 pour que les canaux 5, 6, 7 fonctionnent (cf documentation)
    dmx_data[35] = 255; //canal 4 : luminosité globale de la LED
    dmx_data[36] = 255;  //canal 5 : rouge
    dmx_data[37] = 0;  //canal 6 : vert
    dmx_data[38] = 255;  //canal 7 : bleu
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 255; //canal 4
    dmx_data[44] = 255;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 255;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 255; //canal 4
    dmx_data[52] = 255;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 255;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 255; //canal 4
    dmx_data[60] = 255;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 255;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 255; //canal 4
    dmx_data[52] = 255;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 255;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 255; //canal 4
    dmx_data[44] = 255;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 255;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);}    

void pattern_2(){
//lampe 1
    dmx_data[32] = 0; //canal 1 : entre 0 et 10 pour que les canaux 5, 6, 7 fonctionnent (cf documentation)
    dmx_data[35] = 255; //canal 4 : luminosité globale de la LED
    dmx_data[36] = 240;  //canal 5 : rouge
    dmx_data[37] = 195;  //canal 6 : vert
    dmx_data[38] = 0;  //canal 7 : bleu
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 255; //canal 4
    dmx_data[44] = 240;  //canal 5
    dmx_data[45] = 195;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 255; //canal 4
    dmx_data[52] = 240;  //canal 5
    dmx_data[53] = 195;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 255; //canal 4
    dmx_data[60] = 240;  //canal 5
    dmx_data[61] = 190;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 255; //canal 4
    dmx_data[52] = 240;  //canal 5
    dmx_data[53] = 195;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 255; //canal 4
    dmx_data[44] = 240;  //canal 5
    dmx_data[45] = 195;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);}

    void pattern_3(){
    //lampe 1
    dmx_data[32] = 0; //canal 1 : entre 0 et 10 pour que les canaux 5, 6, 7 fonctionnent (cf documentation)
    dmx_data[35] = 255; //canal 4 : luminosité globale de la LED
    dmx_data[36] = 0;  //canal 5 : rouge
    dmx_data[37] = 255;  //canal 6 : vert
    dmx_data[38] = 255;  //canal 7 : bleu
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 255; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 255;  //canal 6
    dmx_data[46] = 255;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 255; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 255;  //canal 6
    dmx_data[54] = 255;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 255; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 255;  //canal 6
    dmx_data[62] = 255;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 255; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 255;  //canal 6
    dmx_data[54] = 255;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 255; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 255;  //canal 6
    dmx_data[46] = 255;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);}

void pattern_4(){
    //lampe 1
    dmx_data[32] = 0; //canal 1 : entre 0 et 10 pour que les canaux 5, 6, 7 fonctionnent (cf documentation)
    dmx_data[35] = 255; //canal 4 : luminosité globale de la LED
    dmx_data[36] = 204;  //canal 5 : rouge
    dmx_data[37] = 153;  //canal 6 : vert
    dmx_data[38] = 255;  //canal 7 : bleu
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 255; //canal 4
    dmx_data[44] = 204;  //canal 5
    dmx_data[45] = 153;  //canal 6
    dmx_data[46] = 255;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 255; //canal 4
    dmx_data[52] = 204;  //canal 5
    dmx_data[53] = 153;  //canal 6
    dmx_data[54] = 255;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 255; //canal 4
    dmx_data[60] = 204;  //canal 5
    dmx_data[61] = 153;  //canal 6
    dmx_data[62] = 255;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 0; //canal 4
    dmx_data[44] = 0;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 255; //canal 4
    dmx_data[52] = 204;  //canal 5
    dmx_data[53] = 153;  //canal 6
    dmx_data[54] = 255;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 0; //canal 4
    dmx_data[36] = 0;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 255; //canal 4
    dmx_data[44] = 204;  //canal 5
    dmx_data[45] = 153;  //canal 6
    dmx_data[46] = 255;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 0; //canal 4
    dmx_data[52] = 0;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 0; //canal 4
    dmx_data[60] = 0;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50);}

void pattern_5(){
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 255; //canal 4
    dmx_data[36] = 255;  //canal 5
    dmx_data[37] = 0;  //canal 6
    dmx_data[38] = 255;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 255; //canal 4
    dmx_data[44] = 255;  //canal 5
    dmx_data[45] = 255;  //canal 6
    dmx_data[46] = 0;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 255; //canal 4
    dmx_data[52] = 255;  //canal 5
    dmx_data[53] = 0;  //canal 6
    dmx_data[54] = 255;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 255; //canal 4
    dmx_data[60] = 255;  //canal 5
    dmx_data[61] = 255;  //canal 6
    dmx_data[62] = 0;  //canal 7
    updateDMX();
    wait_us(50000);
    //lampe 1
    dmx_data[32] = 0; //canal 1
    dmx_data[35] = 255; //canal 4
    dmx_data[36] = 255;  //canal 5
    dmx_data[37] = 255;  //canal 6
    dmx_data[38] = 0;  //canal 7
    //lampe 2
    dmx_data[40] = 0; //canal 1
    dmx_data[43] = 255; //canal 4
    dmx_data[44] = 255;  //canal 5
    dmx_data[45] = 0;  //canal 6
    dmx_data[46] = 255;  //canal 7
    //lampe 3
    dmx_data[48] = 0; //canal 1
    dmx_data[51] = 255; //canal 4
    dmx_data[52] = 255;  //canal 5
    dmx_data[53] = 255;  //canal 6
    dmx_data[54] = 0;  //canal 7
    //lampe 4
    dmx_data[56] = 0; //canal 1
    dmx_data[59] = 255; //canal 4
    dmx_data[60] = 255;  //canal 5
    dmx_data[61] = 0;  //canal 6
    dmx_data[62] = 255;  //canal 7
    updateDMX();
    wait_us(50000);
    }

//Main
int main() {
    debug_pc.baud(115200);
    debug_pc.printf("Test\r\n");
    
    // Initialisation périphériques
    initDMX(); //initialisation de la connexion DMX
    initMIDI(); //initialisation de la connexion MIDI
    //initMIDI2();
    //initProjectors();
    //initController();

    while(1) { 
        /* MIDI */
        if(isNoteMIDIdetected()){
            //updateProjFromMidi(note_data);
            playNoteMIDI2(note_data, velocity_data);
            if(note_data == 0x2F || note_data == 0x3B || note_data == 0x47 || note_data == 0x53){ //si la note jouée est un Do
                define_color(127, 0, 255, velocity_data);
            }
            else if(note_data == 0x30 || note_data == 0x3C || note_data == 0x48){ //Do#/Réb (Do dièse/Ré bémol)
                define_color(51,51,255, velocity_data);
            }
            else if(note_data == 0x31 || note_data == 0x3D || note_data == 0x49){ //Ré
                define_color(0,0,255, velocity_data);
            }
            else if(note_data == 0x32 || note_data == 0x3E || note_data == 0x4A){ //Ré#/Mib
                define_color(0,128,255, velocity_data);
            } 
            else if(note_data == 0x33 || note_data == 0x3F || note_data == 0x4B){ //Mi
                define_color(0,255,255, velocity_data);
            }
            else if(note_data == 0x34 || note_data == 0x40 || note_data == 0x4C){ //Fa
                define_color(0,255,128, velocity_data);
            }
            else if(note_data == 0x35 || note_data == 0x41 || note_data == 0x4D){ //Fa#/Solb
                define_color(0,255,0, velocity_data);
            }
            else if(note_data == 0x36 || note_data == 0x42 || note_data == 0x4E){ //Sol
                define_color(128,255,0, velocity_data);
            }
            else if(note_data == 0x37 || note_data == 0x43 || note_data == 0x4F){ //Sol#/Lab
                define_color(255,255,0, velocity_data);
            }
            else if(note_data == 0x38 || note_data == 0x44 || note_data == 0x50){ //La
                define_color(255,140,0, velocity_data);
            }
            else if(note_data == 0x39 || note_data == 0x45 || note_data == 0x51){ //La#/Sib
                define_color(255,128,0, velocity_data);
            }
            else if(note_data == 0x3A || note_data == 0x46 || note_data == 0x52){ //Si
                define_color(255,0,0, velocity_data);
            }
            if(note_data == 17){
                pattern_1();
            }
            else if(note_data == 18){
                pattern_2();
            }
            else if(note_data == 19){
                pattern_3();
            } 
            else if(note_data == 20){
                pattern_4();
            }
            else if(note_data == 21){
                define_color(127, 0, 255, velocity_data);
            }
            else if(note_data == 22){
                define_color(51, 51, 255, velocity_data);
            }
            else if(note_data == 23){
                define_color(0, 0, 255, velocity_data);
            }
            else if(note_data == 24){
                define_color(0, 128, 255, velocity_data);
            }
            else if(note_data == 25){
                define_color(0, 255, 255, velocity_data);
            }
            else if(note_data == 26){
                define_color(0, 255, 128, velocity_data);
            }
            else if(note_data == 27){
                define_color(0, 255, 0, velocity_data);
            }
            else if(note_data == 28){
                define_color(128, 255, 0, velocity_data);
            }
            else if(note_data == 29){
                define_color(255, 255, 0, velocity_data);
            }
            else if(note_data == 30){
                define_color(255, 140, 0, velocity_data);
            }
            else if(note_data == 31){
                define_color(255, 128, 0, velocity_data);
            }
            else if(note_data == 32){
                define_color(255 ,0, 0, velocity_data);
            }
            else{
                debug_pc.printf("cas chelou %c\r\n", note_data);   
            }
            resetNoteMIDI();
        }
        
        if(isCCMIDIdetected()){
            playNoteMIDI2(control_ch, control_value); //affichage de la note et de la vélocité dans TeraTerm
            if(control_ch == 1){
                dmx_data[4] = 2 * control_value;
                dmx_data[12] = 2 * control_value;
            }
            resetCCMIDI();
        }
        updateDMX(); //mise à jour du signal envoyé aux LEDs
        wait_us(10000); 
    }
}